compas\_rcf.fabrication package
===============================

.. automodule:: compas_rcf.fabrication
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

compas\_rcf.fabrication.abb\_runner module
------------------------------------------

.. automodule:: compas_rcf.fabrication.abb_runner
   :members:
   :undoc-members:
   :show-inheritance:

compas\_rcf.fabrication.clay\_obj module
----------------------------------------

.. automodule:: compas_rcf.fabrication.clay_obj
   :members:
   :undoc-members:
   :show-inheritance:

compas\_rcf.fabrication.conf module
-----------------------------------

.. automodule:: compas_rcf.fabrication.conf
   :members:
   :undoc-members:
   :show-inheritance:

compas\_rcf.fabrication.network module
--------------------------------------

.. automodule:: compas_rcf.fabrication.network
   :members:
   :undoc-members:
   :show-inheritance:

compas\_rcf.fabrication.ur\_fabrication\_non\_interactive module
----------------------------------------------------------------

.. automodule:: compas_rcf.fabrication.ur_fabrication_non_interactive
   :members:
   :undoc-members:
   :show-inheritance:

compas\_rcf.fabrication.ur\_fabrication\_runner module
------------------------------------------------------

.. automodule:: compas_rcf.fabrication.ur_fabrication_runner
   :members:
   :undoc-members:
   :show-inheritance:
